# Hydromill

[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Poetry](https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json)](https://python-poetry.org/)

## Pub/Subs

Supported Pub/Subs:

- AMQP Pub/Sub [(`hydromill-amqp`)](https://github.com/mczudowski/hydromill-amqp)

## References

[Watermill](https://github.com/ThreeDotsLabs/watermill)

## License

[MIT License](./LICENSE)
